@@ -26,7 +26,7 @@ HTTP::Engine::Interface::CGI - CGI interface for HTTP::Engine
 
   interface:
     module: CGI
-    handle_request: methodname
+    request_handler: methodname
 
 =head1 AUTHOR
 
